@@ -9,7 +9,7 @@ Documento = []
 
 #_print_Symbol
 
-IPython.display.Image(url='https://i.gyazo.com/0842e5162257727d5b10fd6b4abfdab9.png')
+display(IPython.display.Image(url='https://i.gyazo.com/0842e5162257727d5b10fd6b4abfdab9.png'))
 
 def Inicializar(n):
   global DatosList,Orden,Estilo
@@ -155,8 +155,6 @@ def S(c_componente):#Guardar
 def R(string):
   display(IPython.display.Latex(string))  
 
-from ArtemioADaySolvers.latemix import *
-
 def E(expr,color ="black"):
   print("")
   if isinstance(expr,sympy.core.relational.Equality):#Si tenemos una igualdad
